@@ -14,6 +14,7 @@ sub match {
             )
         |delivery[ ]failed:[ ]over[ ]quota
         |disc[ ]quota[ ]exceeded
+        |does[ ]not[ ]have[ ]enough[ ]space
         |exceeded[ ]storage[ ]allocation
         |is[ ]over[ ]quota[ ]temporarily
         |mail[ ](?:
@@ -39,6 +40,7 @@ sub match {
              reached[ ]disk[ ]quota
             |rejected:[ ]mailbox[ ]would[ ]exceed[ ]maximum[ ]allowed[ ]storage
             )
+        |The[ ]recipient[ ]mailbox[ ]has[ ]exceeded[ ]its[ ]disk[ ]space[ ]limit
         |too[ ]much[ ]mail[ ]data   # @docomo.ne.jp
         |user[ ](?:
              has[ ](?:
@@ -80,7 +82,7 @@ sub true {
     my $v = 0;
 
     if( Sisimai::RFC3463->reason( $statuscode ) eq $reasontext ) {
-        # Delivery status code points C<mailboxfull>.
+        # Delivery status code points "mailboxfull".
         # Status: 4.2.2
         # Diagnostic-Code: SMTP; 450 4.2.2 <***@example.jp>... Mailbox Full
         $v = 1;
